@@ -10,20 +10,30 @@ PyDoc_STRVAR(soundRelease_doc,
 	"\n"\
 	"sound.release()");
 
+//update
+PyDoc_STRVAR(soundUpdate_doc,
+	"update the 3d sound paramaters\n"\
+	"\n"\
+	"sound.update()");
+
 //play
 PyDoc_STRVAR(soundPlay_doc,
 	"play the sound \n"\
 	"\n"\
-    "sound.play(filename, stream, loop, volume)\n"\
+    "sound.play(name, stream, loop, is_3d, position, volume)\n"\
 	"\n"\
 	"Parameters\n"\
 	"----------\n"\
-	"    filename : string\n"\
-	"        The sound name\n"\
+	"    name : string or int\n"\
+	"        The sound name or sfxr preset id to play\n"\
 	"    stream : bool (optional)\n"\
 	"        Is streaming support? \n"\
 	"    loop : bool (optional)\n"\
 	"        when it is True, the sound will play and allow it to loop infinitely\n"\
+	"    is_3d : bool (optional)\n"\
+	"        to play 3D\n"\
+	"    position : tuple (optional)\n"\
+	"        (x, y, z) value\n"\
 	"    volume : float (optional)\n"\
 	"        0.0 : 1.0 (default -1.0 that will get from data source = 1.0)\n"\
 	"Returns\n"\
@@ -205,4 +215,58 @@ PyDoc_STRVAR(soundGetGlobalVolume_doc,
 	"\n"\
 	"Returns\n"\
 	"-------\n"\
-	"    global sound volume : float");
\ No newline at end of file
+	"    global sound volume : float");
+
+//getStreamTime
+PyDoc_STRVAR(soundGetStreamTime_doc,
+	"Get the current play position, in seconds\n"\
+	"\n"\
+	"sound.getStreamTime(handle)\n"\
+	"\n"\
+	"Parameters\n"\
+	"----------\n"\
+	"    handle : int\n"\
+	"        The sound handle\n"\
+	"\n"\
+	"Returns\n"\
+	"-------\n"\
+	"    current play position, in seconds : float");
+
+//set3dSourcePosition
+PyDoc_STRVAR(soundSet3dSourcePosition_doc,
+	"set the position parameters of a live 3d audio source. Only evaluated when the update() function is called.\n"\
+	"\n"\
+	"sound.set3dSourcePosition(handle, position)\n"\
+	"\n"\
+	"Parameters\n"\
+	"----------\n"\
+	"    handle : int\n"\
+	"        The sound handle\n"\
+	"    position : tuple (x, y, z)\n"\
+	"        the source position");
+
+//set3dMinMaxDistance
+PyDoc_STRVAR(soundSet3dMinMaxDistance_doc,
+	"set the minimum and maximum distances for the audio source \n"\
+	"\n"\
+	"sound.set3dMinMaxDistance(handle, minmax)\n"\
+	"\n"\
+	"Parameters\n"\
+	"----------\n"\
+	"    handle : int\n"\
+	"        The sound handle\n"\
+	"    minmax : tuple (min, max)\n"\
+	"        the min max value");
+
+//set3dAttenuation
+PyDoc_STRVAR(soundSet3dAttenuation_doc,
+	"set the rolloff factor\n"\
+	"\n"\
+	"sound.set3dAttenuation(handle, rolloffFactor)\n"\
+	"\n"\
+	"Parameters\n"\
+	"----------\n"\
+	"    handle : int\n"\
+	"        The sound handle\n"\
+	"    rolloffFactor : float)\n"\
+	"        the rolloff factor value");
\ No newline at end of file
